Crate snarkos_metrics

Crate snarkos_metrics 

Macros

absolute_counter
counter
decrement_gauge
describe_counter
describe_gauge
describe_histogram
gauge
histogram
increment_counter
increment_gauge
register_counter
register_gauge
register_histogram

Structs

Counter
A counter.
Gauge
A gauge.
Histogram
A histogram.
Key
A metric identifier.
KeyHasher
Key-specific hashing algorithm.
KeyName
Name component of a key.
Label
Metadata for a metric key in the for of a key/value pair.
NoopRecorder
A no-op recorder.
SetRecorderError
The type returned by set_recorder if set_recorder has already been called.

Enums

GaugeValue
Value of a gauge operation.
Unit
Units for a given metric.

Traits

CounterFn
A counter handler.
GaugeFn
A gauge handler.
HistogramFn
A histogram handler.
IntoF64
An object which can be converted into a f64 representation.
IntoLabels
A value that can be converted to a vector of Labels.
Recorder
A trait for registering and recording metrics.

Functions

initialize
recorder
Returns a reference to the recorder.
set_boxed_recorder
Sets the global recorder to a Box<Recorder>.
set_recorder
Sets the global recorder to a &'static Recorder.
set_recorder_racy
A thread-unsafe version of set_recorder.
try_recorder
Returns a reference to the recorder.

Type Aliases

SharedString
An allocation-optimized string.