Macros
- absolute_
counter - counter
- decrement_
gauge - describe_
counter - describe_
gauge - describe_
histogram - gauge
- histogram
- increment_
counter - increment_
gauge - register_
counter - register_
gauge - register_
histogram
Structs
- Counter
- A counter.
- Gauge
- A gauge.
- Histogram
- A histogram.
- Key
- A metric identifier.
- KeyHasher
- Key-specific hashing algorithm.
- KeyName
- Name component of a key.
- Label
- Metadata for a metric key in the for of a key/value pair.
- Noop
Recorder - A no-op recorder.
- SetRecorder
Error - The type returned by
set_recorderifset_recorderhas already been called.
Enums
- Gauge
Value - Value of a gauge operation.
- Unit
- Units for a given metric.
Traits
- Counter
Fn - A counter handler.
- GaugeFn
- A gauge handler.
- Histogram
Fn - A histogram handler.
- IntoF64
- An object which can be converted into a
f64representation. - Into
Labels - A value that can be converted to a vector of
Labels. - Recorder
- A trait for registering and recording metrics.
Functions
- initialize
- recorder
- Returns a reference to the recorder.
- set_
boxed_ recorder - Sets the global recorder to a
Box<Recorder>. - set_
recorder - Sets the global recorder to a
&'static Recorder. - set_
recorder_ ⚠racy - A thread-unsafe version of
set_recorder. - try_
recorder - Returns a reference to the recorder.
Type Aliases
- Shared
String - An allocation-optimized string.